// Copyright 1986-2022 Xilinx, Inc. All Rights Reserved.
// --------------------------------------------------------------------------------
// Tool Version: Vivado v.2022.1 (lin64) Build 3526262 Mon Apr 18 15:47:01 MDT 2022
// Date        : Wed Oct  4 20:03:01 2023
// Host        : atlas-tdaq-firmware-dev.cern.ch running 64-bit CentOS Linux release 7.9.2009 (Core)
// Command     : write_verilog -force -mode synth_stub
//               /home/gitlab-runner/builds/z7w3GeU4/0/atlas-l1calo-efex/RODFirmware/IP/packet_processor/error_ila/error_ila_stub.v
// Design      : error_ila
// Purpose     : Stub declaration of top-level module interface
// Device      : xc7vx550tffg1927-2
// --------------------------------------------------------------------------------

// This empty module with port declaration file causes synthesis tools to infer a black box for IP.
// The synthesis directives are for Synopsys Synplify support to prevent IO buffer insertion.
// Please paste the declaration into a Verilog source file or add the file as an additional source.
(* x_core_info = "ila,Vivado 2022.1" *)
module error_ila(clk, probe0, probe1, probe2, probe3, probe4, probe5, 
  probe6, probe7, probe8, probe9, probe10, probe11, probe12)
/* synthesis syn_black_box black_box_pad_pin="clk,probe0[23:0],probe1[23:0],probe2[0:0],probe3[0:0],probe4[23:0],probe5[0:0],probe6[0:0],probe7[23:0],probe8[0:0],probe9[0:0],probe10[23:0],probe11[0:0],probe12[0:0]" */;
  input clk;
  input [23:0]probe0;
  input [23:0]probe1;
  input [0:0]probe2;
  input [0:0]probe3;
  input [23:0]probe4;
  input [0:0]probe5;
  input [0:0]probe6;
  input [23:0]probe7;
  input [0:0]probe8;
  input [0:0]probe9;
  input [23:0]probe10;
  input [0:0]probe11;
  input [0:0]probe12;
endmodule
